@@ -181,75 +181,6 @@ def method_resize_axes(plot):
             plot.ax.set_zlim3d(plot.bounds_z[0] - plot.pad_lower_z,
                                 plot.bounds_z[1] + plot.pad_upper_z)
 
-def method_cb(plot):
-    if plot.color_bar is True:
-        if plot.color_rule is None:
-            return print("No surface_norm selected for colorbar. Set surface_norm=<parameter of choice>")
-
-        # Obtain and apply limits
-        if plot.cb_vmin is None:
-            plot.cb_vmin = plot.color_rule.min()
-        if plot.cb_vmax is None:
-            plot.cb_vmax = plot.color_rule.max()
-        plot.graph.set_clim([plot.cb_vmin, plot.cb_vmax])
-
-        # Normalization
-        locator = np.linspace(plot.cb_vmin, plot.cb_vmax, plot.cb_tick_number)
-
-        # Colorbar
-        cbar = plot.fig.colorbar(plot.graph,
-                                    ax=plot.ax,
-                                    orientation=plot.cb_orientation, shrink=plot.shrink,
-                                    ticks=locator, boundaries=locator if plot.cb_bounds_hard is True else None,
-                                    spacing='proportional',
-                                    extend=plot.extend,
-                                    format='%.' + str(plot.cb_tick_label_decimals) + 'f',
-                                    pad=plot.cb_pad,
-                                    )
-
-        # Ticks
-        #   Locator
-        cbar.locator = locator
-        #   Direction
-        cbar.ax.tick_params(axis='y', direction='out')
-        #   Tick label pad and size
-        cbar.ax.yaxis.set_tick_params(pad=plot.cb_tick_label_pad, labelsize=plot.cb_tick_label_size)
-
-        # Title
-        if plot.cb_orientation == 'vertical':
-            if plot.cb_title is not None and plot.cb_title_y is False and plot.cb_title_top is False:
-                print('Input colorbar title location with booleans: cb_title_y=True or cb_title_top=True')
-            if plot.cb_title_y is True:
-                cbar.ax.set_ylabel(plot.cb_title, rotation=plot.cb_title_rotation,
-                                    labelpad=plot.cb_title_pad)
-                text = cbar.ax.yaxis.label
-                font = mpl.font_manager.FontProperties(family=plot.font, style=plot.cb_title_style,
-                                                        size=plot.cb_title_size + plot.font_size_increase,
-                                                        weight=plot.cb_title_weight)
-                text.set_font_properties(font)
-            if plot.cb_title_top is True:
-                cbar.ax.set_title(plot.cb_title, rotation=plot.cb_title_rotation,
-                                    fontdict={'verticalalignment': 'baseline',
-                                            'horizontalalignment': 'left'},
-                                    pad=plot.cb_title_pad)
-                cbar.ax.title.set_position((plot.cb_title_top_x, plot.cb_title_top_y))
-                text = cbar.ax.title
-                font = mpl.font_manager.FontProperties(family=plot.font, style=plot.cb_title_style,
-                                                        weight=plot.cb_title_weight,
-                                                        size=plot.cb_title_size + plot.font_size_increase)
-                text.set_font_properties(font)
-        elif plot.cb_orientation == 'horizontal':
-            cbar.ax.set_xlabel(plot.cb_title, rotation=plot.cb_title_rotation, labelpad=plot.cb_title_pad)
-            text = cbar.ax.xaxis.label
-            font = mpl.font_manager.FontProperties(family=plot.font, style=plot.cb_title_style,
-                                                    size=plot.cb_title_size + plot.font_size_increase,
-                                                    weight=plot.cb_title_weight)
-            text.set_font_properties(font)
-
-        # Outline
-        cbar.outline.set_edgecolor(plot.workspace_color2)
-        cbar.outline.set_linewidth(plot.cb_outline_width)
-
 def method_grid(plot):
     if plot.grid:
         plot.plt.grid(linestyle=plot.grid_lines, color=plot.grid_color)
