@@ -25,6 +25,8 @@ from mpl_plotter.three_d.components import text
 
 from mpl_plotter.three_d.mock import MockData
 
+from mpl_plotter.utils import ensure_ndarray
+
 
 class plot(canvas, guides, framing, text):
 
@@ -212,14 +214,18 @@ class scatter(plot):
                  # Color
                  color='darkred', cmap='RdBu_r',
                  # Color bar
-                 color_bar=False, cb_orientation='vertical', shrink=0.75,
-                 extend='neither', cb_vmin=None, cb_vmax=None, cb_bounds_hard=False,
-                 cb_pad=0.1, cb_outline_width=None,                 
-                 cb_tick_number=5, cb_tick_label_decimals=5, cb_tick_label_size=10, cb_tick_label_pad=10,
-                 cb_title=None, cb_title_top=True, cb_title_y=False,
-                 cb_title_top_x=0, cb_title_top_y=1,
-                 cb_title_pad=10, cb_title_weight='normal',
-                 cb_title_rotation=None, cb_title_style='normal', cb_title_size=10,
+                 colorbar=False, cb_orientation='vertical', cb_shrink=1.0,
+                 cb_floating=False, cb_floating_coords=[0.905, 0.165], cb_floating_dimensions=[0.01, 0.8],
+                 cb_anchored_pad=0.2,
+                 cb_norm=None, cb_tick_locs=None, cb_tick_number=5, cb_vmin=None, cb_vmax=None,
+                 cb_title=None, cb_title_size=10, cb_title_rotation=0,
+                 cb_title_font=None, cb_title_style='normal', cb_title_weight='normal',
+                 cb_title_top_loc=None, cb_title_top_pad=None,
+                 cb_title_floating=False, cb_title_floating_coords=[0.0, 1.0], cb_title_floating_transform='transAxes',
+                 cb_title_anchored_side=False, cb_title_anchored_pad=0.2,
+                 cb_tick_label_decimals=1, cb_tick_label_size=10, cb_tick_label_pad=5,
+                 cb_hard_bounds=False, cb_extend='neither',
+                 cb_outline_width=None, cb_outline_color=None,
                  # Scale
                  scale_x=None,
                  scale_y=None,
@@ -333,7 +339,7 @@ class scatter(plot):
                                          s=self.scatter_size, marker=self.scatter_marker, facecolors=self.scatter_facecolors,
                                          c=self.color_rule, cmap=self.cmap,
                                          alpha=self.scatter_alpha)
-            self.method_cb()
+            self.method_colorbar()
         else:
             self.graph = self.ax.scatter(self.x, self.y, self.z, label=self.plot_label,
                                          s=self.scatter_size, marker=self.scatter_marker, facecolors=self.scatter_facecolors,
@@ -359,14 +365,18 @@ class surface(plot):
                  # Specifics: color
                  cmap='RdBu_r', color=None, color_rule=None,
                  # Color bar
-                 color_bar=False, cb_orientation='vertical', shrink=0.75,
-                 extend='neither', cb_vmin=None, cb_vmax=None, cb_bounds_hard=False,
-                 cb_pad=0.1, cb_outline_width=None,                 
-                 cb_tick_number=5, cb_tick_label_decimals=5, cb_tick_label_size=10, cb_tick_label_pad=10,
-                 cb_title=None, cb_title_top=True, cb_title_y=False,
-                 cb_title_top_x=0, cb_title_top_y=1,
-                 cb_title_pad=10, cb_title_weight='normal',
-                 cb_title_rotation=None, cb_title_style='normal', cb_title_size=10,
+                 colorbar=False, cb_orientation='vertical', cb_shrink=1.0,
+                 cb_floating=False, cb_floating_coords=[0.905, 0.165], cb_floating_dimensions=[0.01, 0.8],
+                 cb_anchored_pad=0.2,
+                 cb_norm=None, cb_tick_locs=None, cb_tick_number=5, cb_vmin=None, cb_vmax=None,
+                 cb_title=None, cb_title_size=10, cb_title_rotation=0,
+                 cb_title_font=None, cb_title_style='normal', cb_title_weight='normal',
+                 cb_title_top_loc=None, cb_title_top_pad=None,
+                 cb_title_floating=False, cb_title_floating_coords=[0.0, 1.0], cb_title_floating_transform='transAxes',
+                 cb_title_anchored_side=False, cb_title_anchored_pad=0.2,
+                 cb_tick_label_decimals=1, cb_tick_label_size=10, cb_tick_label_pad=5,
+                 cb_hard_bounds=False, cb_extend='neither',
+                 cb_outline_width=None, cb_outline_color=None,
                  # Scale
                  scale_x=None,
                  scale_y=None,
@@ -488,93 +498,79 @@ class surface(plot):
         self.init()
 
     def plot(self):
+        
+        kwargs = {
+            "alpha":          self.surface_alpha,
+            "edgecolors":     self.surface_edge_color,
+            "rstride":        self.surface_rstride,
+            "cstride":        self.surface_cstride,
+            "linewidth":      self.surface_wire_width,
+            "antialiased":    self.surface_antialiased,
+            "shade":          self.surface_shade
+        }
+        
         if self.surface_lighting:
-            # Lightning
-            self.graph = self.ax.plot_surface(self.x, self.y, self.z,
-                                              alpha=self.surface_alpha,
-                                              cmap=self.cmap if self.color is None else None,
-                                              norm=self.surface_norm, color=self.color,
-                                              edgecolors=self.surface_edge_color,
-                                              facecolors=self.method_lighting(),
-                                              rstride=self.surface_rstride, cstride=self.surface_cstride, linewidth=self.surface_wire_width,
-                                              surface_antialiased=self.surface_antialiased, shade=self.surface_shade,
-                                              )
+            kwargs.update({
+                "cmap":       self.cmap if self.color is None else None,
+                "norm":       self.surface_norm,
+                "color":      self.color,
+                "facecolors": self.method_lighting()
+            })
         elif self.color_rule is not None:
-            # Colormap
-            cmap = mpl.cm.get_cmap(self.cmap) if not isinstance(self.cmap, mpl.colors.LinearSegmentedColormap) else self.cmap
-            surface_facecolors = cmap((self.color_rule + abs(self.color_rule.min()))/(self.color_rule.max() + abs(self.color_rule.min())))
-
-            self.graph = self.ax.plot_surface(self.x, self.y, self.z,
-                                              alpha=self.surface_alpha,
-                                              cmap=self.cmap,
-                                              norm=self.surface_norm,
-                                              facecolors=surface_facecolors,
-                                              edgecolors=self.surface_edge_color,
-                                              rstride=self.surface_rstride, cstride=self.surface_cstride, linewidth=self.surface_wire_width,
-                                              antialiased=self.surface_antialiased, shade=self.surface_shade,
-                                              )
+            kwargs.update({
+                "cmap":       mpl.cm.get_cmap(self.cmap) if not isinstance(self.cmap, mpl.colors.LinearSegmentedColormap) else self.cmap,
+                "norm":       self.surface_norm,
+                "facecolors": cmap((self.color_rule + abs(self.color_rule.min()))/(self.color_rule.max() + abs(self.color_rule.min())))
+            })
         elif self.surface_norm is not None:
-            self.graph = self.ax.plot_surface(self.x, self.y, self.z,
-                                              alpha=self.surface_alpha,
-                                              cmap=self.cmap,
-                                              norm=self.surface_norm,
-                                              edgecolors=self.surface_edge_color,
-                                              rstride=self.surface_rstride, cstride=self.surface_cstride, linewidth=self.surface_wire_width,
-                                              antialiased=self.surface_antialiased, shade=self.surface_shade,
-                                              )
+            kwargs.update({
+                "cmap":       self.cmap,
+                "norm":       self.surface_norm
+            })
         else:
-            # No colormap
-            self.graph = self.ax.plot_surface(self.x, self.y, self.z,
-                                              alpha=self.surface_alpha,
-                                              color=self.color,
-                                              edgecolors=self.surface_edge_color,
-                                              rstride=self.surface_rstride, cstride=self.surface_cstride, linewidth=self.surface_wire_width,
-                                              antialiased=self.surface_antialiased, shade=self.surface_shade,
-                                              )
+            kwargs.update({
+                "color":      self.color
+            })
 
-        self.method_cb()
+        self.graph = self.ax.plot_surface(self.x, self.y, self.z, **kwargs)
+            
+        self.method_colorbar()
         self.method_edges_to_rgba()
 
     def mock(self):
         if self.x is None and self.y is None and self.z is None:
             self.x, self.y, self.z = MockData().hill()
-            self.surface_norm = mpl.colors.Normalize(vmin=self.z.min(), vmax=self.z.max())
+            self.surface_norm = self.cb_norm = mpl.colors.Normalize(vmin=self.z.min(), vmax=self.z.max())
 
     def method_lighting(self):
+        
         ls = LightSource(270, 45)
 
         if self.color is not None:
             if self.surface_cmap_lighting is None:
                 try:
                     cmap = difflib.get_close_matches(self.color, self.plt.colormaps())[0]
-                    print_color(
-                        f'You have selected the solid _color_ "{self.color}" for your surface, and set _lighting_ as True\n\n'
-                        f'   The search for Matplotlib colormaps similar to "{self.color}" has resulted in: \n',
-                        "blue")
+                    print(f'You have selected the solid **color** "{self.color}" for your surface, and set **lighting** as **True**\n\n'
+                          f'   The search for Matplotlib colormaps similar to "{self.color}" has resulted in: \n')
                     print(f'       "{cmap}"\n')
-                    print_color(
-                        '   Specify a custom colormap for the lighting function with the _surface_cmap_lighting_ attribute.\n'
-                        '   NOTE: This will overrule your monochrome color, however. Set _lighting_ to False if this is undesired.',
-                        "blue")
+                    print('   Specify a custom colormap for the lighting function with the **surface_cmap_lighting** attribute.\n'
+                          '   NOTE: This will overrule your monochrome color, however. Set **lighting** to **False** if this is undesired.')
                 except IndexError:
                     cmap = "Greys"
-                    print_color(
-                        f'You have selected the solid _color_ "{self.color}" for your surface, and set _lighting_ as True\n\n'
-                        f'   The search for Matplotlib colormaps similar to "{self.color}" has failed. Reverting to\n',
-                        "red")
+                    print(f'You have selected the solid _color_ "{self.color}" for your surface, and set _lighting_ as True\n\n'
+                          f'   The search for Matplotlib colormaps similar to "{self.color}" has failed. Reverting to\n')
                     print(f'       "{cmap}"\n')
-                    print_color(
-                        '   Specify a custom colormap for the lighting function with the _surface_cmap_lighting_ attribute.\n'
-                        '   NOTE: This will overrule your monochrome color, however. Set _lighting_ to False if this is undesired.',
-                        "red")
+                    print('   Specify a custom colormap for the lighting function with the _surface_cmap_lighting_ attribute.\n'
+                          '   NOTE: This will overrule your monochrome color, however. Set _lighting_ to False if this is undesired.')
             else:
-                cmap = self.surface_cmap_lighting
+                cmap = self.surface_cmap_lighting if self.surface_cmap_lighting is not None else self.cmap
         else:
             cmap = self.surface_cmap_lighting if self.surface_cmap_lighting is not None else self.cmap
-
-        rgb = ls.surface_shade(self.z,
+            
+        rgb = ls.shade(self.z,
                        cmap=cm.get_cmap(cmap),
-                       vert_exag=0.1, blend_mode='soft')
+                       vert_exag=0.1,
+                       blend_mode='soft')
 
         return rgb
 
