@@ -6,6 +6,7 @@ Composition: ``panes``
 ----------------------
 """
 
+import os
 
 import numpy as np
 import matplotlib as mpl
@@ -18,7 +19,7 @@ from mpl_plotter import figure
 from mpl_plotter.two_d import line
 from mpl_plotter.two_d.comparison import comparison
 
-from mpl_plotter.utils import home
+from mpl_plotter.utils import tmp
 
 
 def panes(x,
@@ -128,6 +129,8 @@ def panes(x,
       ``colors=[['red', 'blue'], ['green', 'red']]`` to a plot containing 2 panes with 2 curves
       each will color the curves in the first pane red and blue, and those in the second green and red.
 
+    **Arguments**
+    
     :param x:        Data
     :param y:        Data
     :param f:        List of plotting functions to use for each curve
@@ -156,6 +159,10 @@ def panes(x,
     :type right:     float
     :type wspace:    float
     :type hspace:    float
+
+    **Output**
+
+    :param panes:    list of lists, each containing the objects output by each Matplotlib plotting function used
     """
 
     ###############################
@@ -272,7 +279,7 @@ def panes(x,
     ###############################
     #            PLOT             #
     ###############################
-
+    
     shape = (M, N) if shape is None else shape
     
     for n in range(n_plots):
@@ -350,9 +357,9 @@ def panes(x,
                    Y,
                    F,
                    ax=ax_transient, fig=fig,
-
+                   
                    legend=args.pop('legend') if n == n_plots-1 else False,         # Avoid conflict
-
+                   
                    **args
                    )
 
@@ -371,7 +378,7 @@ def panes(x,
 
         # Save figure (necessary step for correct legend positioning, thanks to
         # the _bbox_extra_artists_ argument of _plt.savefig_)
-        plt.savefig(f"{home()}/temp.pdf",
+        plt.savefig(os.path.join(tmp(), 'tmp.pdf'),
                     bbox_extra_artists=legend,
                     )
     if show:
