@@ -1,13 +1,21 @@
 import os
 
+from sys import platform
+from pathlib import Path
+
 import numpy as np
 
 
-def home():
+def tmp():
     """
-    :return: User home directory.
+    Return the machine's temporary file directory.
     """
-    return os.environ['HOME']
+    
+    tmp = os.path.join('/tmp/' if platform != 'win32' else os.environ['TEMP'], '.mpl_plotter')
+    
+    Path(tmp).mkdir(parents=True, exist_ok=True)
+    
+    return tmp
 
 
 def ensure_ndarray(a):
@@ -54,4 +62,4 @@ def bounds(d, u, l, up, lp, v):
             v[0] = l
         if isinstance(v[1], type(None)):
             v[1] = u
-        return v, up, lp
\ No newline at end of file
+        return v, up, lp
